# tetrad_plus

This project provides a python interface to the java Tetrad program from cmu.

The primary motivation was to provide a set of commands that could be used in a jupyter notebook. Combined with the dgraph_flex package, it supports the interactive use of causal discovery algorithms such as gfci, running of a SEM using the causal graph and data, and creation of publication quality graphs using the graphviz program.
